@@ -1,7 +1,6 @@
 package Minion::Command::minion::job;
 use Mojo::Base 'Mojolicious::Command';
 
-use Mojo::Date;
 use Mojo::JSON 'decode_json';
 use Mojo::Util qw(dumper getopt tablify);
 
@@ -18,6 +17,7 @@ sub run {
     'b|broadcast=s' => (\my $command),
     'd|delay=i'     => \$options->{delay},
     'e|enqueue=s'   => \my $enqueue,
+    'f|foreground'  => \my $foreground,
     'l|limit=i'  => \(my $limit          = 100),
     'o|offset=i' => \(my $offset         = 0),
     'P|parent=s' => ($options->{parents} = []),
@@ -31,11 +31,11 @@ sub run {
     'w|workers'    => \my $workers;
 
   # Worker remote control command
-  return $self->app->minion->backend->broadcast($command, $args, \@args)
-    if $command;
+  my $minion = $self->app->minion;
+  return $minion->backend->broadcast($command, $args, \@args) if $command;
 
   # Enqueue
-  return say $self->app->minion->enqueue($enqueue, $args, $options) if $enqueue;
+  return say $minion->enqueue($enqueue, $args, $options) if $enqueue;
 
   # Show stats
   return $self->_stats if $stats;
@@ -45,7 +45,7 @@ sub run {
   return $id ? $self->_worker($id) : $self->_list_workers($offset, $limit)
     if $workers;
   return $self->_list_jobs($offset, $limit, $options) unless defined $id;
-  die "Job does not exist.\n" unless my $job = $self->app->minion->job($id);
+  die "Job does not exist.\n" unless my $job = $minion->job($id);
 
   # Remove job
   return $job->remove || die "Job is active.\n" if $remove;
@@ -53,24 +53,20 @@ sub run {
   # Retry job
   return $job->retry($options) || die "Job is active.\n" if $retry;
 
-  # Job info
-  print dumper _datetime($job->info);
-}
+  # Perform job in foreground
+  return $minion->foreground($id) || die "Job is not ready.\n" if $foreground;
 
-sub _datetime {
-  my $hash = shift;
-  $hash->{$_} and $hash->{$_} = Mojo::Date->new($hash->{$_})->to_datetime
-    for qw(created delayed finished notified retried started);
-  return $hash;
+  # Job info
+  print dumper Minion::_datetime($job->info);
 }
 
 sub _list_jobs {
-  my $jobs = shift->app->minion->backend->list_jobs(@_);
+  my $jobs = shift->app->minion->backend->list_jobs(@_)->{jobs};
   print tablify [map { [@$_{qw(id state queue task)}] } @$jobs];
 }
 
 sub _list_workers {
-  my $workers = shift->app->minion->backend->list_workers(@_);
+  my $workers = shift->app->minion->backend->list_workers(@_)->{workers};
   my @workers = map { [$_->{id}, $_->{host} . ':' . $_->{pid}] } @$workers;
   print tablify \@workers;
 }
@@ -78,9 +74,10 @@ sub _list_workers {
 sub _stats { print dumper shift->app->minion->stats }
 
 sub _worker {
-  die "Worker does not exist.\n"
-    unless my $worker = shift->app->minion->backend->worker_info(@_);
-  print dumper _datetime($worker);
+  my $worker = shift->app->minion->backend->list_workers(0, 1, {ids => [shift]})
+    ->{workers}[0];
+  die "Worker does not exist.\n" unless $worker;
+  print dumper Minion::_datetime($worker);
 }
 
 1;
@@ -100,6 +97,7 @@ Minion::Command::minion::job - Minion job command
     ./myapp.pl minion job -w
     ./myapp.pl minion job -w 23
     ./myapp.pl minion job -s
+    ./myapp.pl minion job -f 10023
     ./myapp.pl minion job -q important -t foo -S inactive
     ./myapp.pl minion job -e foo -a '[23, "bar"]'
     ./myapp.pl minion job -e foo -P 10023 -P 10024 -p 5 -q important
@@ -117,6 +115,9 @@ Minion::Command::minion::job - Minion job command
                                 workers
     -d, --delay <seconds>       Delay new job for this many seconds
     -e, --enqueue <task>        New job to be enqueued
+    -f, --foreground            Retry job in "minion_foreground" queue and
+                                perform it right away in the foreground (very
+                                useful for debugging)
     -h, --help                  Show this summary of available options
         --home <path>           Path to home directory of your application,
                                 defaults to the value of MOJO_HOME or
